pplite: Convex polyhedra library
================================

Description
-----------

PPLite is an open-source C++ library implementing the abstract domain
of convex polyhedra.

While being derived from the PPL (Parma Polyhedra Library), PPLite has
a very different goal: to provide researchers and students with a
lighter framework for experimenting with new ideas and algorithms in
the context of polyhedral computations.

License
-------

GPL 3

Upstream Contact
----------------

https://github.com/ezaffanella/PPLite
